CommunityStrings class
Partial string overrides for community UI. Unset fields fall back to l10n.
Constructors
- CommunityStrings({String? pageTitle, String? joinCommunity, String? continueWithGoogle, String? continueWithApple, String? noCommunitiesFound, String? noPostsYet, String? loginRequired, String? loginRequiredLike, String? loginRequiredComment, String? errorGeneric, String? likeFailed, String? commentFailed, String? commentLoadFailed, String? commentEmpty, String? commentAdded, String? commentCreateFailed, String? likeCommentFailed})
-
const
Properties
- commentAdded → String?
-
final
- commentCreateFailed → String?
-
final
- commentEmpty → String?
-
final
- commentFailed → String?
-
final
- commentLoadFailed → String?
-
final
-
final
- continueWithApple → String?
-
final
- continueWithGoogle → String?
-
final
- errorGeneric → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- joinCommunity → String?
-
final
- likeCommentFailed → String?
-
final
- likeFailed → String?
-
final
- loginRequired → String?
-
final
- loginRequiredComment → String?
-
final
- loginRequiredLike → String?
-
final
- noCommunitiesFound → String?
-
final
- noPostsYet → String?
-
final
- pageTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
merge(
CommunityStrings? other) → CommunityStrings -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited